@@ -230,7 +230,7 @@ fi
 # NOTE(jeffrey4l): The local_settings file affect django-compress
 # behavior, so re-generate the compressed javascript and css if it
 # is changed
-MD5SUM_TXT_PATH="/tmp/.local_settings.md5sum.txt"
+MD5SUM_TXT_PATH="/var/lib/kolla/.local_settings.md5sum.txt"
 if [[ ! -f ${MD5SUM_TXT_PATH} || $(md5sum -c --status ${MD5SUM_TXT_PATH};echo $?) != 0 || ${FORCE_GENERATE} == "yes" ]]; then
     md5sum /etc/openstack-dashboard/local_settings > ${MD5SUM_TXT_PATH}
     if [[ "${KOLLA_INSTALL_TYPE}" == "binary" ]]; then
