@@ -17,10 +17,8 @@ if [[ "${KOLLA_BASE_DISTRO}" =~ debian|ubuntu ]]; then
     # Loading Apache2 ENV variables
     . /etc/apache2/envvars
     rm -rf /var/run/apache2/*
-    APACHE_DIR="apache2"
 else
     rm -rf /var/run/httpd/* /run/httpd/* /tmp/httpd*
-    APACHE_DIR="httpd"
 fi
 
 # Create log dir for Keystone logs
