@@ -18,17 +18,15 @@ from mock import patch
 from oslo_log import fixture as log_fixture
 from oslo_log import log as logging
 from oslotest import base
-import six
 import testtools
 
 sys.path.append(
     os.path.abspath(os.path.join(os.path.dirname(__file__), '../tools')))
-from kolla.cmd import build
+from kolla.image import build
 
 LOG = logging.getLogger(__name__)
 
 
-@six.add_metaclass(abc.ABCMeta)
 class BuildTest(object):
     excluded_images = abc.abstractproperty()
 
@@ -43,10 +41,10 @@ class BuildTest(object):
     def runTest(self):
         with patch.object(sys, 'argv', self.build_args):
             LOG.info("Running with args %s", self.build_args)
-            bad_results, good_results, unmatched_results = build.main()
+            bad_results, good_results, unmatched_results = build.run_build()
 
         failures = 0
-        for image, result in six.iteritems(bad_results):
+        for image, result in bad_results.items():
             if image in self.excluded_images:
                 if result is 'error':
                     continue
@@ -67,12 +65,24 @@ class BuildTest(object):
 
 
 class BuildTestCentosBinary(BuildTest, base.BaseTestCase):
-    excluded_images = ["marathon",
-                       "murano-base",
-                       "ironic-pxe",
-                       "ironic-inspector",
-                       "mistral-base",
-                       "murano-base"]
+    excluded_images = [
+        "bifrost-base",
+        "congress-base",
+        "freezer-base",
+        "kafka",
+        "karbor-base",
+        "kuryr-base",
+        "manila-data",
+        "monasca-base",
+        "neutron-sfc-agent",
+        "searchlight-base",
+        "senlin-base",
+        "solum-base",
+        "tacker",
+        "vitrage-base",
+        "vmtp",
+        "zun-base",
+    ]
 
     def setUp(self):
         super(BuildTestCentosBinary, self).setUp()
@@ -81,12 +91,10 @@ class BuildTestCentosBinary(BuildTest, base.BaseTestCase):
 
 
 class BuildTestCentosSource(BuildTest, base.BaseTestCase):
-    excluded_images = ["marathon",
-                       "gnocchi-base",
-                       "murano-base",
-                       "ironic-pxe",
-                       "ironic-inspector",
-                       "mistral-base"]
+    excluded_images = [
+        "kafka",
+        "mistral-base",
+    ]
 
     def setUp(self):
         super(BuildTestCentosSource, self).setUp()
@@ -95,12 +103,26 @@ class BuildTestCentosSource(BuildTest, base.BaseTestCase):
 
 
 class BuildTestUbuntuBinary(BuildTest, base.BaseTestCase):
-    # NOTE(jeffrey4l): there is no gnocchi and tempest packages in Mitaka repo
-    excluded_images = ["gnocchi-base",
-                       "mistral-base",
-                       "tempest",
-                       "magnum-base",
-                       "zaqar"]
+    excluded_images = [
+        "bifrost-base",
+        "cloudkitty-base",
+        "congress-base",
+        "freezer-base",
+        "karbor-base",
+        "kuryr-base",
+        "monasca-base",
+        "neutron-sfc-agent",
+        "octavia-base",
+        "panko-base",
+        "searchlight-base",
+        "senlin-base",
+        "solum-base",
+        "tacker",
+        "vitrage-base",
+        "vmtp",
+        "zaqar",
+        "zun-base",
+    ]
 
     def setUp(self):
         super(BuildTestUbuntuBinary, self).setUp()
@@ -118,12 +140,24 @@ class BuildTestUbuntuSource(BuildTest, base.BaseTestCase):
 
 
 class BuildTestOracleLinuxBinary(BuildTest, base.BaseTestCase):
-    excluded_images = ["marathon",
-                       "murano-base",
-                       "ironic-pxe",
-                       "ironic-inspector",
-                       "mistral-base",
-                       "murano-base"]
+    excluded_images = [
+        "bifrost-base",
+        "congress-base",
+        "freezer-base",
+        "kafka",
+        "karbor-base",
+        "kuryr-base",
+        "manila-data",
+        "monasca-base",
+        "neutron-sfc-agent",
+        "searchlight-base",
+        "senlin-base",
+        "solum-base",
+        "tacker",
+        "vitrage-base",
+        "vmtp",
+        "zun-base",
+    ]
 
     def setUp(self):
         super(BuildTestOracleLinuxBinary, self).setUp()
@@ -132,7 +166,9 @@ class BuildTestOracleLinuxBinary(BuildTest, base.BaseTestCase):
 
 
 class BuildTestOracleLinuxSource(BuildTest, base.BaseTestCase):
-    excluded_images = ["marathon"]
+    excluded_images = [
+        "kafka",
+    ]
 
     def setUp(self):
         super(BuildTestOracleLinuxSource, self).setUp()
